﻿using System;
using System.Text;

using RabbitMQ.Client;
using RabbitMQ.Client.Events;

namespace TestConsumer
{
    /// <summary>
    /// 프로그램
    /// </summary>
    class Program
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Private

        #region 프로그램 시작하기 - Main()

        /// <summary>
        /// 프로그램 시작하기
        /// </summary>
        private static void Main()
        {
            ConnectionFactory factory = new ConnectionFactory() { HostName = "localhost" };

            using(IConnection connection = factory.CreateConnection())
            {
                using(IModel model = connection.CreateModel())
                {
                    model.QueueDeclare
                    (
                        queue      : "hello",
                        durable    : false,
                        exclusive  : false,
                        autoDelete : false,
                        arguments  : null
                    );

                    EventingBasicConsumer consumer = new EventingBasicConsumer(model);

                    consumer.Received += (sender, e) =>
                    {
                        byte[] messageArray = e.Body;
                        string message      = Encoding.UTF8.GetString(messageArray);

                        WriteLog("수신 : {0}", message);
                    };

                    model.BasicConsume
                    (
                        queue    : "hello",
                        autoAck  : true,
                        consumer : consumer
                    );

                    Console.WriteLine("프로그램을 종료하기 위해 아무 키나 눌러 주시기 바랍니다.");

                    Console.ReadKey(true);
                }
            }
        }

        #endregion
        #region 로그 작성하기 - WriteLog(format, parameterArray)

        /// <summary>
        /// 로그 작성하기
        /// </summary>
        /// <param name="format">포맷 문자열</param>
        /// <param name="parameterArray">매개 변수 배열</param>
        private static void WriteLog(string format, params object[] parameterArray)
        {
            string message;

            if(parameterArray.Length == 0)
            {
                message = format;
            }
            else
            {
                message = string.Format(format, parameterArray);
            }

            string log = string.Format("[{0}] {1}", DateTime.Now.ToString("HH:mm:ss"), message);

            Console.WriteLine(log);
        }

        #endregion
    }
}